# `BioClients.ensembl`

## EnsEMBL

Access to Ensembl REST API.

* <http://rest.ensembl.org/documentation/info/lookup>

## `BioClients.ensembl.biomart`

Also, the BIOMART ID mapping service.

* <https://m.ensembl.org/info/data/biomart/biomart_restful.html>
